ewa.ply.lex

Package ewa :: Package ply :: Module lex |
[hide private]
[frames] | no frames]

# Module lex

source code

Version: 3.3

Classes | [hide private]
| LexError
| LexToken
| PlyLogger
| NullLogger
| Lexer
| LexerReflect

Functions | [hide private]
func_code(f) | source code
get_caller_module_dict(levels) | source code
_funcs_to_names(funclist, namelist) | source code
_names_to_funcs(namelist, fdict) | source code
_form_master_re(relist, reflags, ldict, toknames) | source code
_statetoken(s, names) | source code
lex(module=None, object=None, debug=0, optimize=0, lextab=`'``lextab``'`, reflags=0, nowarn=0, outputdir=`'````'`, debuglog=None, errorlog=None) | source code
runmain(lexer=None, data=None) | source code
TOKEN(r) | source code
Token(r) | source code

Variables | [hide private]
| __tabversion__ = ``'``3.2``'``
| StringTypes = ``(`<type 'str'>`,` <type 'unicode'>`)``
| _is_identifier = `re.compile(r'^`[`a`-`zA`-`Z0`-`9_`]``+`$')`
| __package__ = ``'``ewa.ply``'``